==> hibernate-search-mapper-pojo-base-6.1.5.Final.jar: META-INF/versions/9/module-info.java <==
/* synthetic */ module org.hibernate.search.mapper.pojo {
    requires java.sql;
    requires org.hibernate.commons.annotations;
    requires org.hibernate.search.engine;
    requires org.hibernate.search.util.common;
    requires org.jboss.logging;

    exports org.hibernate.search.mapper.pojo.automaticindexing;
    exports org.hibernate.search.mapper.pojo.automaticindexing.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.automaticindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.automaticindexing.spi;
    exports org.hibernate.search.mapper.pojo.bridge;
    exports org.hibernate.search.mapper.pojo.bridge.binding;
    exports org.hibernate.search.mapper.pojo.bridge.binding.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.binding.spi;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.alternative.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.annotation;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.annotation.processor.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.programmatic;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.spatial.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.mapping;
    exports org.hibernate.search.mapper.pojo.bridge.mapping.annotation;
    exports org.hibernate.search.mapper.pojo.bridge.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.mapping.programmatic;
    exports org.hibernate.search.mapper.pojo.bridge.mapping.programmatic.identifiertovalue.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.runtime;
    exports org.hibernate.search.mapper.pojo.bridge.runtime.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.runtime.spi;
    exports org.hibernate.search.mapper.pojo.common.annotation;
    exports org.hibernate.search.mapper.pojo.common.annotation.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.extractor;
    exports org.hibernate.search.mapper.pojo.extractor.builtin;
    exports org.hibernate.search.mapper.pojo.extractor.builtin.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.extractor.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.extractor.mapping.annotation;
    exports org.hibernate.search.mapper.pojo.extractor.mapping.programmatic;
    exports org.hibernate.search.mapper.pojo.extractor.spi;
    exports org.hibernate.search.mapper.pojo.identity.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.identity.spi;
    exports org.hibernate.search.mapper.pojo.loading.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.loading.spi;
    exports org.hibernate.search.mapper.pojo.logging.impl to org.jboss.logging;
    exports org.hibernate.search.mapper.pojo.logging.spi;
    exports org.hibernate.search.mapper.pojo.mapping.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.building.spi;
    exports org.hibernate.search.mapper.pojo.mapping.definition.annotation;
    exports org.hibernate.search.mapper.pojo.mapping.definition.annotation.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.definition.annotation.processing;
    exports org.hibernate.search.mapper.pojo.mapping.definition.annotation.processing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.definition.programmatic;
    exports org.hibernate.search.mapper.pojo.mapping.definition.programmatic.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.spi;
    exports org.hibernate.search.mapper.pojo.massindexing;
    exports org.hibernate.search.mapper.pojo.massindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.massindexing.spi;
    exports org.hibernate.search.mapper.pojo.model;
    exports org.hibernate.search.mapper.pojo.model.additionalmetadata.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.additionalmetadata.building.spi;
    exports org.hibernate.search.mapper.pojo.model.additionalmetadata.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.dependency;
    exports org.hibernate.search.mapper.pojo.model.dependency.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.hcann.spi;
    exports org.hibernate.search.mapper.pojo.model.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.path;
    exports org.hibernate.search.mapper.pojo.model.path.binding.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.path.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.path.spi;
    exports org.hibernate.search.mapper.pojo.model.spi;
    exports org.hibernate.search.mapper.pojo.model.typepattern.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.processing.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.processing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.processing.spi;
    exports org.hibernate.search.mapper.pojo.reporting.impl to org.jboss.logging;
    exports org.hibernate.search.mapper.pojo.route;
    exports org.hibernate.search.mapper.pojo.route.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.schema.management.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.schema.management.spi;
    exports org.hibernate.search.mapper.pojo.scope.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.scope.spi;
    exports org.hibernate.search.mapper.pojo.search.loading.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.session.spi;
    exports org.hibernate.search.mapper.pojo.work.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.work.spi;

}

==> hibernate-search-mapper-pojo-base-6.1.7.Final.jar: META-INF/versions/9/module-info.java <==
/* synthetic */ module org.hibernate.search.mapper.pojo {
    requires java.sql;
    /* transitive */ requires org.hibernate.commons.annotations;
    /* transitive */ requires org.hibernate.search.engine;
    /* transitive */ requires org.hibernate.search.util.common;
    requires org.jboss.logging;

    exports org.hibernate.search.mapper.pojo.automaticindexing;
    exports org.hibernate.search.mapper.pojo.automaticindexing.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.automaticindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.automaticindexing.spi;
    exports org.hibernate.search.mapper.pojo.bridge;
    exports org.hibernate.search.mapper.pojo.bridge.binding;
    exports org.hibernate.search.mapper.pojo.bridge.binding.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.binding.spi;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.alternative.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.annotation;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.annotation.processor.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.programmatic;
    exports org.hibernate.search.mapper.pojo.bridge.builtin.spatial.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.mapping;
    exports org.hibernate.search.mapper.pojo.bridge.mapping.annotation;
    exports org.hibernate.search.mapper.pojo.bridge.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.mapping.programmatic;
    exports org.hibernate.search.mapper.pojo.bridge.mapping.programmatic.identifiertovalue.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.runtime;
    exports org.hibernate.search.mapper.pojo.bridge.runtime.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.bridge.runtime.spi;
    exports org.hibernate.search.mapper.pojo.common.annotation;
    exports org.hibernate.search.mapper.pojo.common.annotation.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.extractor;
    exports org.hibernate.search.mapper.pojo.extractor.builtin;
    exports org.hibernate.search.mapper.pojo.extractor.builtin.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.extractor.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.extractor.mapping.annotation;
    exports org.hibernate.search.mapper.pojo.extractor.mapping.programmatic;
    exports org.hibernate.search.mapper.pojo.extractor.spi;
    exports org.hibernate.search.mapper.pojo.identity.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.identity.spi;
    exports org.hibernate.search.mapper.pojo.loading.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.loading.spi;
    exports org.hibernate.search.mapper.pojo.logging.impl to org.jboss.logging, org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.logging.spi;
    exports org.hibernate.search.mapper.pojo.mapping.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.building.spi;
    exports org.hibernate.search.mapper.pojo.mapping.definition.annotation;
    exports org.hibernate.search.mapper.pojo.mapping.definition.annotation.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.definition.annotation.processing;
    exports org.hibernate.search.mapper.pojo.mapping.definition.annotation.processing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.definition.programmatic;
    exports org.hibernate.search.mapper.pojo.mapping.definition.programmatic.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.mapping.spi;
    exports org.hibernate.search.mapper.pojo.massindexing;
    exports org.hibernate.search.mapper.pojo.massindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.massindexing.spi;
    exports org.hibernate.search.mapper.pojo.model;
    exports org.hibernate.search.mapper.pojo.model.additionalmetadata.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.additionalmetadata.building.spi;
    exports org.hibernate.search.mapper.pojo.model.additionalmetadata.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.dependency;
    exports org.hibernate.search.mapper.pojo.model.dependency.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.hcann.spi;
    exports org.hibernate.search.mapper.pojo.model.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.path;
    exports org.hibernate.search.mapper.pojo.model.path.binding.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.path.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.model.path.spi;
    exports org.hibernate.search.mapper.pojo.model.spi;
    exports org.hibernate.search.mapper.pojo.model.typepattern.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.processing.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.processing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.processing.spi;
    exports org.hibernate.search.mapper.pojo.reporting.impl to org.jboss.logging, org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.route;
    exports org.hibernate.search.mapper.pojo.route.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.schema.management.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.schema.management.spi;
    exports org.hibernate.search.mapper.pojo.scope.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.scope.spi;
    exports org.hibernate.search.mapper.pojo.search.loading.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.session.spi;
    exports org.hibernate.search.mapper.pojo.work.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.work.spi;

}
